import re
import inspect
import platform
import subprocess
import sys
import colorama
from colorama import Fore, Back, Style

def library_info():
    print(
    "----------------------------------------------------------------\n"
    "  Library Name: ChatCMD\n"
    "  Library Source [PyPi]: https://pypi.org/naifalshaye/chatcmd\n"
    "  Library Source [Github]: https://github.com/naifalshaye/chatcmd\n"
    "  Documentation: https://github.com/naifalshaye/chatcmd#readme\n"
    "  Bug Tracker: https://github.com/naifalshaye/chatcmd/issues\n"
    "  Published Date: 2023-05-15\n"
    "  License: MIT\n"
    "  Author: Naif Alshaye\n"
    "  Author Email: naif@naif.io\n"
    "  Author Website: https://naif.io\n"
    "----------------------------------------------------------------"
    )

def color_text(text, color):
    colors = {
        'red': Fore.RED,
        'green': Fore.GREEN,
        'yellow': Fore.YELLOW,
        'blue': Fore.BLUE,
        'magenta':Fore.MAGENTA,
        'cyan': Fore.CYAN,
        'white':Fore.WHITE,
        'black':Fore.BLACK,
    }

    return f"{colors[color]}{text}" + Style.RESET_ALL

def success_msg(text):
    print("\n"+color_text(text, 'green'))

def error_msg(text):
    print("\n"+color_text(text, 'red'))
    exit()

def warning_msg(text):
    print("\n"+color_text(text, 'yellow'))

def clear_input(input):
    input = re.sub('[^a-zA-Z0-9 -_=]', '', input.strip())
    return input

def validateInput(prompt):
    if len(prompt.split()) <= 2:
        return False
    return True

def validate_api_key(api_key):
    if api_key[0:3] != 'sk-':
        return False
    if len(api_key) != 51:
        return False
    if not re.match("^[a-zA-Z0-9-]+$", api_key):
        return False
    return True

def copy_to_clipboard(text):
    try:
        system = platform.system()
        if system == 'Darwin':  # macOS
            subprocess.run(['pbcopy'], input=text, encoding='utf-8')
        elif system == 'Linux':  # Linux
            subprocess.run(['xclip', '-selection', 'clipboard'], input=text, encoding='utf-8')
        elif system == 'Windows':  # Windows
            subprocess.run(['clip'], input=text, encoding='utf-8', shell=True)
    except Exception as e:
        error_msg("Error 1018: Failed to copy command. "+str(e))

def get_line_number():
    frame = inspect.currentframe().f_back
    return frame.f_lineno